@@ -12,7 +12,7 @@ class BaseAPI:
     """
     _BASE_URL = 'https://api.withmono.com'
 
-    def __init__(self, mono_sec_key: str) -> None:
+    def __init__(self, mono_sec_key: str = None) -> None:
         if mono_sec_key is None:
             raise MonoAuthException('your mono secret key is required.')
 
@@ -28,7 +28,7 @@ class BaseAPI:
 
     def _make_request(self, method, url, **kwargs):
 
-        http_methods = {
+        HTTP_METHODS = {
             'GET': requests.get,
             'POST': requests.post,
             'PUT': requests.put,
@@ -36,13 +36,15 @@ class BaseAPI:
         }
 
         params = kwargs.get('params', None)
+        json = kwargs.get('json', None)
 
-        request = http_methods.get(method, None)
+        request = HTTP_METHODS.get(method, None)
 
         if request is None:
-            raise HttpMethodException('unrecognize method. you may only use POST, GET, PUT or DELETE')
+            raise HttpMethodException('unrecognized HTTP method; you may only use POST, GET, PUT or DELETE')
+
+        response = request(headers=self._headers(), url=url, params=params, json=json)
 
-        response = request(headers=self._headers(), url=url, params=params)
 
         if response.status_code >= 400:
             return response.status_code, response.json()
@@ -50,4 +52,4 @@ class BaseAPI:
 
 
     def __repr__(self):
-        return 'MonopyAPI <%r>' % self._mono_sec_key[:5]
+        return '%s <%r>' % (self.__class__.__name__, self._mono_sec_key[:5])
